@@ -36,10 +36,13 @@ class Firestore:
         __ref__.set(data, merge=True)
         logging.debug(f"Document written successfully")
 
+
+
     def write_doc_auto_id(self, collection: str, data: dict):
         __ref__ = self.firestore_db.collection(collection)
-        __ref__.add(data, merge=True)
+        ref = __ref__.add(data)
         logging.debug(f"Document written successfully")
+        return ref      #this function will return tuple
 
     def update_doc(self, collection: str, doc: str, data: dict):
         __ref__ = self.firestore_db.collection(collection).document(doc)
