@@ -5,8 +5,8 @@ from upswingutil.channel import trigger_reservation_email
 from upswingutil.channel.email import TriggerReservationEmailModel
 from upswingutil.db.model import Status, ReservationGuestInfo, ReservationGuestShort, \
     ReservationModelV2, GuestsModelV2
-from upswingutil.pms import store_reservation_to_alvie
-from upswingutil.resource import get_model_from_cloud_storage
+from upswingutil.pms import store_reservation_to_alvie, store_reservation_to_alvie_v2
+from upswingutil.resource import get_model_from_cloud_storage, FirebaseHelper
 from upswingutil.pms.rms import NAME, get_key, validate_key
 from upswingutil.db import Mongodb, Firestore, MongodbV2
 from upswingutil.resource.user_management import create_and_update_app_user_profile
@@ -295,6 +295,7 @@ class ReservationSync:
         self.orgId = orgId
         self.mongo = Mongodb(orgId)
         self.mongoV2 = MongodbV2(orgId)
+        self.firebase = FirebaseHelper(appName='alvie')
         self.firestore_db = Firestore(app='alvie')
         self.token: Token = get_key(self.orgId)
         self.g_cloud_token = g_cloud_token
@@ -579,11 +580,16 @@ class ReservationSync:
             for guest in record.get('guests'):
                 _guest_profile = self._transform_guest_profile(self._extract_guest_profile(guest))
                 self.mongoV2.save(_guest_profile)
+                auth_result = self.firebase.find_user_by_email(_guest_profile.contactInfo.get('email'))
                 _guest_list.append(ReservationGuestShort(
                     guest=str(guest.get('id')),
                     primary=guest.get('id') == record.get("guestId"),
                     arrivalTransport=None,
-                    departureTransport=None
+                    departureTransport=None,
+                    appGuestUID=auth_result.uid if auth_result else '',
+                    appAccess=True,
+                    doorlockAccess=True,
+                    grmsAccess=True,
                 ))
         except Exception as e:
             logging.error('Error getting guest list')
@@ -897,8 +903,8 @@ class ReservationSync:
             record = self.transform_reservation(self.extract_reservation_details(record))
             if record:
                 self.mongoV2.save(record)
-                store_reservation_to_alvie(record)
-                _create_guestprofile(record)
+                store_reservation_to_alvie_v2(record)
+                # _create_guestprofile(record) // TODO: To be removed
                 _trigger_email(record)
             else:
                 logging.error(f'Error saving the record {record} as it is None')
