@@ -7,4 +7,6 @@ from .reservation import Reservation
 from .country import Country
 from .organization_cfg import CommunicationMethodsEntDetails,HotelTaxType, LeisureActivityTypes
 from .http import ResponseList, ResponseDict
-from .user_management import GuestUserProfileModel, BookingsModel
\ No newline at end of file
+from .user_management import GuestUserProfileModel, BookingsModel
+from .qr_codes import AlvieQRGenerateorModels
+from .checkin import CheckinReservationModel, CheckInGuestModel, GuestType
