@@ -12,4 +12,4 @@ class ResponseList(BaseModel):
 class ResponseDict(BaseModel):
     status: bool = False
     message: str = 'default error msg'
-    data: dict
+    data: dict = {}
